GridTrack

Enum GridTrack 

pub enum GridTrack {
    Points(f32),
    Percent(f32),
    Fr(f32),
    Auto,
    MinContent,
    MaxContent,
    MinMax(Box<GridTrack>, Box<GridTrack>),
    Repeat {
        count: u16,
        tracks: Vec<GridTrack>,
    },
    AutoFit(Box<GridTrack>),
    AutoFill(Box<GridTrack>),
}

Variants



Points(f32)

Fixed track size in logical points.



Percent(f32)

Percentage of the available grid axis. 50.0 means 50%.



Fr(f32)

Fraction of remaining free space after fixed and intrinsic tracks.



Auto

Track sized by the largest participating item’s intrinsic size.



MinContent

Track sized by the participating items’ minimum intrinsic size.



MaxContent

Track sized by the participating items’ preferred intrinsic size.



MinMax(Box<GridTrack>, Box<GridTrack>)

Track with independent minimum and maximum sizing functions.



Repeat

Repeats an ordered track list a fixed number of times.

Fields

count: u16
tracks: Vec<GridTrack>


AutoFit(Box<GridTrack>)

Repeats a track to fit available space, dropping empty trailing tracks.



AutoFill(Box<GridTrack>)

Repeats a track to fill available space, retaining empty tracks.

Implementations

Source

impl GridTrack

pub fn minmax(min: GridTrack, max: GridTrack) -> GridTrack

Creates a minmax(min, max) grid track.

Example
use fission_ir::op::GridTrack;

let track = GridTrack::minmax(GridTrack::Points(180.0), GridTrack::Fr(1.0));
pub fn repeat(count: u16, tracks: impl Into<Vec<GridTrack>>) -> GridTrack

Repeats tracks count times.

pub fn auto_fit(track: GridTrack) -> GridTrack

Repeats track up to the available space and collapses empty tracks.

pub fn auto_fill(track: GridTrack) -> GridTrack

Repeats track up to the available space and keeps empty tracks.