pub struct LayoutSize {
pub width: LayoutUnit,
pub height: LayoutUnit,
}Expand description
A 2D size in layout coordinate space.
Represents a width and height in logical pixels. Used as the output of layout measurement and as input to constraints.
Fields
width: LayoutUnitWidth in logical pixels.
height: LayoutUnitHeight in logical pixels.
Implementations
Sourceimpl LayoutSize
impl LayoutSize
Sourcepub fn new(width: LayoutUnit, height: LayoutUnit) -> Self
pub fn new(width: LayoutUnit, height: LayoutUnit) -> Self
Creates a new size from width and height values.