pub struct ParagraphCluster {
pub start_index: usize,
pub end_index: usize,
pub line_index: usize,
pub rect: LayoutRect,
pub is_rtl: bool,
}Expand description
One visually positioned shaping cluster. Byte ranges always fall on UTF-8 boundaries and may contain more than one scalar value (for example a ligature, combining sequence, or emoji ZWJ sequence).
Fields
start_index: usizeend_index: usizeline_index: usizerect: LayoutRectis_rtl: boolTrait Implementations
Sourceimpl Clone for ParagraphCluster
impl Clone for ParagraphCluster
Sourcefn clone(&self) -> ParagraphCluster
fn clone(&self) -> ParagraphCluster
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ParagraphCluster
Sourceimpl Debug for ParagraphCluster
impl Debug for ParagraphCluster
Sourceimpl<'de> Deserialize<'de> for ParagraphCluster
impl<'de> Deserialize<'de> for ParagraphCluster
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ParagraphCluster
impl PartialEq for ParagraphCluster
Sourceimpl Serialize for ParagraphCluster
impl Serialize for ParagraphCluster
impl StructuralPartialEq for ParagraphCluster