pub enum LayoutOp {
Show 16 variants
Box {
width: Option<f32>,
height: Option<f32>,
min_width: Option<f32>,
max_width: Option<f32>,
min_height: Option<f32>,
max_height: Option<f32>,
padding: [f32; 4],
flex_grow: f32,
flex_shrink: f32,
aspect_ratio: Option<f32>,
},
StyledBox {
style: BoxStyle,
flex_grow: f32,
flex_shrink: f32,
},
Flex {
direction: FlexDirection,
wrap: FlexWrap,
flex_grow: f32,
flex_shrink: f32,
padding: [f32; 4],
gap: Option<f32>,
align_items: AlignItems,
justify_content: JustifyContent,
},
Grid {
columns: Vec<GridTrack>,
rows: Vec<GridTrack>,
column_gap: Option<f32>,
row_gap: Option<f32>,
padding: [f32; 4],
},
GridItem {
row_start: GridPlacement,
row_end: GridPlacement,
col_start: GridPlacement,
col_end: GridPlacement,
},
Responsive {
query: ResponsiveQuery,
cases: Vec<ResponsiveCondition>,
},
Scroll {
direction: FlexDirection,
show_scrollbar: bool,
width: Option<f32>,
height: Option<f32>,
min_width: Option<f32>,
max_width: Option<f32>,
min_height: Option<f32>,
max_height: Option<f32>,
padding: [f32; 4],
flex_grow: f32,
flex_shrink: f32,
},
Embed {
kind: EmbedKind,
widget_id: WidgetId,
width: Option<f32>,
height: Option<f32>,
},
AbsoluteFill,
Positioned {
left: Option<f32>,
top: Option<f32>,
right: Option<f32>,
bottom: Option<f32>,
width: Option<f32>,
height: Option<f32>,
},
PositionedLengths {
left: Option<Length>,
top: Option<Length>,
right: Option<Length>,
bottom: Option<Length>,
width: Option<Length>,
height: Option<Length>,
},
ZStack,
Align,
Flyout {
anchor: WidgetId,
content: WidgetId,
},
Transform {
transform: [f32; 16],
},
Clip {
path: Option<String>,
},
}Variants
Box
Fields
StyledBox
A common box using declarative length expressions.
Flex
Grid
Fields
GridItem
Fields

row_start: GridPlacement
row_end: GridPlacement
col_start: GridPlacement
col_end: GridPlacementResponsive
Selects one case child or the final fallback child from local constraints.
Scroll
Fields

direction: FlexDirectionEmbed
AbsoluteFill
Positioned
Fields
PositionedLengths
Absolutely positions a child using typed lengths resolved by layout.
Fields
ZStack
Align
Flyout
Transform
Clip