pub struct LineMetric {
pub start_index: usize,
pub end_index: usize,
pub baseline: LayoutUnit,
pub height: LayoutUnit,
pub width: LayoutUnit,
}Expand description
Per-line metrics from the same shaped paragraph used for paint and hit testing.
Fields
start_index: usizeByte index where this line starts in the source string.
end_index: usizeByte index where this line ends in the source string (exclusive).
baseline: LayoutUnitDistance from the top of the paragraph to the alphabetic baseline.
height: LayoutUnitTotal line height, including leading.
width: LayoutUnitShaped width of the line.